@@ -4,7 +4,7 @@ use warnings;
 
 use Carp qw(croak);
 
-our $VERSION = '0.07_01';
+our $VERSION = '0.07_02';
 
 require XSLoader;
 XSLoader::load('RPi::DHT11', $VERSION);
@@ -86,7 +86,7 @@ at the command line).
 
 Parameters:
 
-=head3 $pin
+    $pin
 
 Mandatory. Pin number for the DHT11 sensor's DATA pin (values are 0-40).
 
@@ -98,7 +98,7 @@ Returns an integer of the temperature, in celcius by default.
 
 Parameters:
 
-=head3 $f
+    $f
 
 Send in the string char C<'f'> to receive the temp in Farenheit.
 
@@ -113,70 +113,6 @@ Returns the humidity as either an integer of the current humidity level.
 Returns the pin back to default state if it's not already. Called automatically
 by C<DESTROY()>.
 
-=head1 C TYPEDEFS
-
-=head2 EnvData
-
-Stores the temperature and humidity float values.
-
-    typedef struct env_data {
-        int temp;
-        int humidity;
-    } EnvData;
-
-=head1 C FUNCTIONS
-
-=head2 c_temp
-
-    int c_temp(int spin);
-
-Called by the C<temp()> method.
-
-=head2 c_humidity
-
-    int c_humidity(int spin);
-
-Called by the C<humidity()> method.
-
-=head2 c_cleanup
-
-    int c_cleanup(int spin, int tpin, int hpin);
-
-Called by the C<cleanup()> method, and is always called upon C<DESTROY()>.
-
-=head2 read_env()
-
-    EnvData read_env(int spin);
-
-Not available to Perl.
-
-Polls the pin in a loop until valid data is fetched, then  returns an C<EnvData>
-struct containing the temp and humidity float values.
-
-If for any reason the poll of the DHT11 sensor fails (eg: the CRC is incorrect
-for either temp or humidity), we will loop and block until valid data is
-retrieved.
-
-=head2 noboard_test()
-
-    bool noboard_test();
-
-Checks whether the C<RDE_NOBOARD_TEST> environment variable is set to a true
-value. Returns true if so, and false if not. This bool is used for testing
-purposes only.
-
-Not available to Perl.
-
-=head2 sanity()
-
-    void sanity();
-
-If we're on a system that isn't a Raspberry Pi, things break. We call this in
-C<new()>, and if sanity checks fail, we exit (unless in RDE_NOBOARD_TEST
-environment variable is set to true).
-
-Called only from the C<new()> method.
-
 =head1 ENVIRONMENT VARIABLES
 
 There are a couple of env vars to help prototype and run unit tests when not on
